<!-- Copyright © SixtyFPS GmbH <info@slint.dev> ; SPDX-License-Identifier: MIT -->
## `VerticalBox`

A `VerticalBox` is a [`VerticalLayout`](../builtins/elements.md#verticallayout-and-horizontallayout) where the spacing and padding values
depend on the style instead of defaulting to 0.

See also [`HorizontalBox`](horizontalbox.md).
